"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const anypoint_cli_command_1 = require("anypoint-cli-command");
const core_1 = require("@oclif/core");
const flags_1 = require("anypoint-cli-command/lib/core/flags");
const _ = require("lodash");
const uris_1 = require("../../../helpers/uris");
const utils_1 = require("../../../helpers/utils");
class List extends anypoint_cli_command_1.AuthenticationBaseCommand {
    async run() {
        await this.runtimesList();
    }
    async runtimesList() {
        var _a, _b;
        try {
            const res = await this.req.get(uris_1.runtimes);
            const muleVersions = res.data.data;
            const table = [];
            const header = ['Runtime', 'Release Channel', 'Java Version'];
            table.push(header);
            _.each(muleVersions, function (muleVersion) {
                if (muleVersion.state === 'ACTIVE' || muleVersion.state === 'DEFAULT') {
                    var releaseChannel = muleVersion.releaseChannel ? muleVersion.releaseChannel : utils_1.LEGACY_RELEASE_CHANNEL;
                    var javaVersion = muleVersion.javaVersion ? muleVersion.javaVersion : utils_1.DEFAULT_JAVA_VERSION;
                    const muleVersionData = [
                        muleVersion.version,
                        releaseChannel,
                        javaVersion,
                    ];
                    table.push(muleVersionData);
                }
            });
            await this.show(table, muleVersions);
        }
        catch (error) {
            const errorMsg = ((_b = (_a = error.response) === null || _a === void 0 ? void 0 : _a.data) === null || _b === void 0 ? void 0 : _b.message) ? error.response.data.message : error;
            this.error(errorMsg);
        }
    }
}
exports.default = List;
List.description = 'Lists all Mule Runtimes';
List.flags = {
    ...anypoint_cli_command_1.AuthenticationBaseCommand.flags,
    help: core_1.Flags.help({ char: 'h' }),
    ...flags_1.OutputFlag,
};
